@@ -10,3 +10,5 @@ Created on Wed Apr  1 14:56:15 2020
 """
 from .input_setup import InputHipims
 from .output_setup import OutputHipims
+from .Raster import Raster
+from .Boundary import Boundary
