@@ -16,7 +16,7 @@ import gzip
 import numpy as np
 import pandas as pd
 import spatial_analysis as sp
-from raster import Raster
+from .Raster import Raster
 class OutputHipims:
     """To read and analyze otuput files from a HiPIMS flood model
     Properties (public):
